@@ -1,6 +1,6 @@
 package Sub::Spec::CmdLine;
 BEGIN {
-  $Sub::Spec::CmdLine::VERSION = '0.01';
+  $Sub::Spec::CmdLine::VERSION = '0.02';
 }
 # ABSTRACT: Access Perl subs via command line
 
@@ -87,12 +87,12 @@ sub parse_argv {
 
     $log->tracef("tmp args result (after YAML conversion): %s", $args);
 
-    # process arg_order
+    # process arg_pos
   ARGV:
     for my $i (reverse 0..@$argv-1) {
         while (my ($name, $schema) = each %$spec_args) {
             my $ah0 = $schema->{attr_hashes}[0];
-            my $o = $ah0->{arg_order};
+            my $o = $ah0->{arg_pos};
             if (defined($o) && $o == $i) {
                 die "You specified option --$name but also argument #".
                     ($i+1)."\n" if defined($args->{$name});
@@ -106,7 +106,7 @@ sub parse_argv {
         }
     }
 
-    $log->tracef("tmp args result (after arg_order processing): %s, argv: %s",
+    $log->tracef("tmp args result (after arg_pos processing): %s, argv: %s",
                  $args, $argv);
     die "Error: extra argument(s): ".join(", ", @$argv)."\n" if @$argv;
 
@@ -153,8 +153,8 @@ sub gen_usage($;$) {
     for my $name (sort {
         (($args->{$a}{attr_hashes}[0]{arg_category} // "") cmp
              ($args->{$b}{attr_hashes}[0]{arg_category} // "")) ||
-                 (($args->{$a}{attr_hashes}[0]{arg_order} // 9999) <=>
-                      ($args->{$b}{attr_hashes}[0]{arg_order} // 9999)) ||
+                 (($args->{$a}{attr_hashes}[0]{arg_pos} // 9999) <=>
+                      ($args->{$b}{attr_hashes}[0]{arg_pos} // 9999)) ||
                           ($a cmp $b) } keys %$args) {
         my $arg = $args->{$name};
         my $ah0 = $arg->{attr_hashes}[0];
@@ -177,7 +177,7 @@ sub gen_usage($;$) {
             $arg_desc  .= "[" . $arg->{type} . "]";
         }
 
-        my $o = $ah0->{arg_order};
+        my $o = $ah0->{arg_pos};
         my $g = $ah0->{arg_greedy};
 
         $arg_desc .= " $ah0->{summary}" if $ah0->{summary};
@@ -373,7 +373,7 @@ Sub::Spec::CmdLine - Access Perl subs via command line
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -388,6 +388,7 @@ In your module:
          arg  => ...,
          arg2 => ...
      },
+     ...
  };
  sub foo {
     ...
@@ -400,7 +401,6 @@ In your script:
 
  #!/usr/bin/perl
  use Sub::Spec::CmdLine qw(run);
- use YourModule;
  run(module=>'YourModule', sub=>'foo');
 
 In the command-line:
@@ -408,13 +408,34 @@ In the command-line:
  % script.pl --help
  % script.pl --arg value --arg2 '[an, array, in, yaml, syntax]' ...
 
+For running multiple subs, in your script:
+
+ use Sub::Spec::CmdLine qw(run);
+ run(subcommands => {
+     foo => { module=>'YourModule', sub=>'foo'},
+     bar => { module=>'YourModule', sub=>'bar'},
+     ...
+ });
+
+In the command-line:
+
+ % script.pl --help
+ % script.pl --list
+ % script.pl foo --help
+ % script.pl foo --arg value --arg2 ...
+ % script.pl bar --blah ...
+
 =head1 DESCRIPTION
 
+This module utilize sub specs (as defined by L<Sub::Spec>) to let your subs be
+accessible from the command-line.
+
+This module uses L<Log::Any> logging framework. Use something like
+L<Log::Any::App>, etc to see more logging statements for debugging.
+
 NOTE: This module is not ready for public consumption yet. It will be after
 L<Data::Sah> and L<Sub::Spec> is released.
 
-This module uses Log::Any logging framework.
-
 =head1 FUNCTIONS
 
 None of the functions are exported by default, but they are exportable.
@@ -431,7 +452,7 @@ Note: As with GetOptions, this function modifies its argument, @argv.
 
 Why would one use this function instead of using Getopt::Long directly? We want
 YAML parsing (ability to pass data structures via command line), parsing of
-arg_order and arg_greedy, stricter behaviour (dies on error).
+arg_pos and arg_greedy, stricter behaviour (dies on error).
 
 One problem with Getopt::Long: all options get set to undef even if not
 specified. So currently we delete undef keys in %$args.
